module

package
v0.9.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 24, 2026 License: BSD-3-Clause Imports: 22 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func JSONResponse

func JSONResponse(msg any) (*tr.Response, error)

func ProtoResponse

func ProtoResponse(msg proto.Message) (*tr.Response, error)

Types

type AuthContext

type AuthContext struct {
	// contains filtered or unexported fields
}

func NewAuthContext

func NewAuthContext(steamID id.ID) *AuthContext

func (*AuthContext) Community

func (m *AuthContext) Community() community.Requester

func (*AuthContext) MockCommunity

func (m *AuthContext) MockCommunity() *cm.Mock

func (*AuthContext) SteamID

func (m *AuthContext) SteamID() id.ID

type InitContext

type InitContext struct {
	// contains filtered or unexported fields
}

func NewInitContext

func NewInitContext() *InitContext

func (*InitContext) AssertPacketHandlerRegistered

func (m *InitContext) AssertPacketHandlerRegistered(t *testing.T, e enums.EMsg)

func (*InitContext) AssertPacketHandlerUnregistered

func (m *InitContext) AssertPacketHandlerUnregistered(t *testing.T, e enums.EMsg)

func (*InitContext) AssertServiceHandlerRegistered

func (m *InitContext) AssertServiceHandlerRegistered(t *testing.T, serviceMethod string)

AssertServiceHandlerRegistered verifies that a handler for the specific method exists.

func (*InitContext) AssertServiceHandlerUnregistered

func (m *InitContext) AssertServiceHandlerUnregistered(t *testing.T, serviceMethod string)

AssertServiceHandlerUnregistered verifies that a handler for the specific method does NOT exist.

func (*InitContext) Bus

func (m *InitContext) Bus() *bus.Bus

func (*InitContext) EmitPacket

func (m *InitContext) EmitPacket(t *testing.T, e enums.EMsg, msg proto.Message)

func (*InitContext) GetPacketHandler

func (m *InitContext) GetPacketHandler(method enums.EMsg) (socket.Handler, bool)

func (*InitContext) GetServiceHandler

func (m *InitContext) GetServiceHandler(method string) (socket.Handler, bool)

func (*InitContext) Logger

func (m *InitContext) Logger() log.Logger

func (*InitContext) MockService

func (m *InitContext) MockService() *requester.Mock

func (*InitContext) MockServiceAccessor

func (m *InitContext) MockServiceAccessor() *requester.Mock

func (*InitContext) Module

func (m *InitContext) Module(name string) module.Module

func (*InitContext) RegisterPacketHandler

func (m *InitContext) RegisterPacketHandler(e enums.EMsg, h socket.Handler)

func (*InitContext) RegisterServiceHandler

func (m *InitContext) RegisterServiceHandler(method string, h socket.Handler)

func (*InitContext) Rest

func (m *InitContext) Rest() aoni.Requester

func (*InitContext) Service

func (m *InitContext) Service() service.Doer

func (*InitContext) SetModule

func (m *InitContext) SetModule(name string, mod module.Module)

func (*InitContext) SetService

func (m *InitContext) SetService(s *requester.Mock)

func (*InitContext) SetStorage

func (m *InitContext) SetStorage(s storage.Provider)

func (*InitContext) Storage

func (m *InitContext) Storage() storage.Provider

func (*InitContext) UnregisterPacketHandler

func (m *InitContext) UnregisterPacketHandler(e enums.EMsg)

func (*InitContext) UnregisterServiceHandler

func (m *InitContext) UnregisterServiceHandler(method string)

Jump to